@@ -39,19 +39,19 @@
 
 #include <kjanuswidget.h>
 #include <kurl.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstatusbar.h>
-#include <kconfig.h>
-#include <kwin.h>
+#include <tdeconfig.h>
+#include <twin.h>
 #include <kcombobox.h>
-#include <kmenubar.h>
+#include <tdemenubar.h>
 #include <kstandarddirs.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
+#include <tdeaboutdata.h>
+#include <tdecmdlineargs.h>
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <kaction.h>
-#include <kactionclasses.h>
+#include <tdeaction.h>
+#include <tdeactionclasses.h>
 #include <kstdaction.h>
 #include <kuniqueapplication.h>
 #include <kkeydialog.h>
@@ -97,7 +97,7 @@ public:
 
 KPilotInstaller::KPilotInstaller() :
 	DCOPObject("KPilotIface"),
-	KMainWindow(0),
+	TDEMainWindow(0),
 	fDaemonStub(new PilotDaemonDCOP_stub("kpilotDaemon",
 		"KPilotDaemonIface")),
 	fP(new KPilotPrivate),
@@ -167,7 +167,7 @@ void KPilotInstaller::startDaemonIfNeeded()
 		fDaemonWasRunning = true;
 	}
 
-	if (!fDaemonWasRunning && KApplication::startServiceByDesktopName(
+	if (!fDaemonWasRunning && TDEApplication::startServiceByDesktopName(
 		CSL1("kpilotdaemon"),
 		TQString(), &daemonError, &daemonDCOP, &daemonPID
 			, "0" /* no notify */
@@ -255,7 +255,7 @@ void KPilotInstaller::initComponents()
 	TQWidget *w;
 
 #define ADDICONPAGE(a,b) \
-	pixmap = KGlobal::iconLoader()->loadIcon(b, KIcon::Desktop, 64); \
+	pixmap = TDEGlobal::iconLoader()->loadIcon(b, TDEIcon::Desktop, 64); \
 	w = getManagingWidget()->addVBoxPage(a,TQString(), pixmap) ;
 
 	ADDICONPAGE(i18n("HotSync"),CSL1("kpilotbhotsync"));
@@ -508,11 +508,11 @@ void KPilotInstaller::initMenu()
 {
 	FUNCTIONSETUP;
 
-	KAction *a;
+	TDEAction *a;
 
-	KActionMenu *syncPopup;
+	TDEActionMenu *syncPopup;
 
-	syncPopup = new KActionMenu(i18n("HotSync"), CSL1("kpilot"),
+	syncPopup = new TDEActionMenu(i18n("HotSync"), CSL1("kpilot"),
 		actionCollection(), "popup_hotsync");
 	syncPopup->setToolTip(i18n("Select the kind of HotSync to perform next."));
 	syncPopup->setWhatsThis(i18n("Select the kind of HotSync to perform next. "
@@ -522,7 +522,7 @@ void KPilotInstaller::initMenu()
 		TQT_TQOBJECT(this), TQT_SLOT(slotHotSyncRequested()));
 
 	// File actions, keep this list synced with kpilotui.rc and pilotDaemon.cc
-	a = new KAction(i18n("&HotSync"), CSL1("hotsync"), 0,
+	a = new TDEAction(i18n("&HotSync"), CSL1("hotsync"), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotHotSyncRequested()),
 		actionCollection(), "file_hotsync");
 	a->setToolTip(i18n("Next HotSync will be normal HotSync."));
@@ -530,7 +530,7 @@ void KPilotInstaller::initMenu()
 		"should be a normal HotSync."));
 	syncPopup->insert(a);
 
-	a = new KAction(i18n("Full&Sync"), CSL1("fullsync"), 0,
+	a = new TDEAction(i18n("Full&Sync"), CSL1("fullsync"), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotFullSyncRequested()),
 		actionCollection(), "file_fullsync");
 	a->setToolTip(i18n("Next HotSync will be a FullSync."));
@@ -538,7 +538,7 @@ void KPilotInstaller::initMenu()
 		"should be a FullSync (check data on both sides)."));
 	syncPopup->insert(a);
 
-	a = new KAction(i18n("&Backup"), CSL1("backup"), 0,
+	a = new TDEAction(i18n("&Backup"), CSL1("backup"), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotBackupRequested()),
 		actionCollection(), "file_backup");
 	a->setToolTip(i18n("Next HotSync will be backup."));
@@ -546,7 +546,7 @@ void KPilotInstaller::initMenu()
 		"should back up the Handheld to the PC."));
 	syncPopup->insert(a);
 
-	a = new KAction(i18n("&Restore"), CSL1("restore"), 0,
+	a = new TDEAction(i18n("&Restore"), CSL1("restore"), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotRestoreRequested()),
 		actionCollection(), "file_restore");
 	a->setToolTip(i18n("Next HotSync will be restore."));
@@ -554,7 +554,7 @@ void KPilotInstaller::initMenu()
 		"should restore the Handheld from data on the PC."));
 	syncPopup->insert(a);
 
-	a = new KAction(i18n("Copy Handheld to PC"), TQString(), 0,
+	a = new TDEAction(i18n("Copy Handheld to PC"), TQString(), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotHHtoPCRequested()),
 		actionCollection(), "file_HHtoPC");
 	a->setToolTip(i18n("Next HotSync will be backup."));
@@ -563,7 +563,7 @@ void KPilotInstaller::initMenu()
 		"overwriting entries on the PC."));
 	syncPopup->insert(a);
 
-	a = new KAction(i18n("Copy PC to Handheld"), TQString(), 0,
+	a = new TDEAction(i18n("Copy PC to Handheld"), TQString(), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotPCtoHHRequested()),
 		actionCollection(), "file_PCtoHH");
 	a->setToolTip(i18n("Next HotSync will copy PC to Handheld."));
@@ -574,7 +574,7 @@ void KPilotInstaller::initMenu()
 
 
 #if 0
-	a = new KAction(i18n("&List Only"),CSL1("listsync"),0,
+	a = new TDEAction(i18n("&List Only"),CSL1("listsync"),0,
 		this,TQT_SLOT(slotTestSyncRequested()),
 		actionCollection(), "file_list");
 	a->setToolTip(i18n("Next HotSync will list databases."));
@@ -585,7 +585,7 @@ void KPilotInstaller::initMenu()
 #endif
 
 
-	a = new KAction(i18n("Rese&t Link"),CSL1("reload"), 0,
+	a = new TDEAction(i18n("Rese&t Link"),CSL1("reload"), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotResetLink()),
 		actionCollection(),"file_reload");
 	a->setToolTip(i18n("Reset the device connection."));
@@ -610,7 +610,7 @@ void KPilotInstaller::initMenu()
 	(void) KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(configure()),
 		actionCollection());
 
-	a = new KAction(i18n("Configuration &Wizard..."), CSL1("wizard"), 0,
+	a = new TDEAction(i18n("Configuration &Wizard..."), CSL1("wizard"), 0,
 		TQT_TQOBJECT(this), TQT_SLOT(configureWizard()),
 		actionCollection(), "options_configure_wizard");
 	a->setWhatsThis(i18n("Configure KPilot using the configuration wizard."));
@@ -683,8 +683,8 @@ void KPilotInstaller::addComponentPage(PilotComponent * p,
 		strlcat(actionname, componentname, actionnameLength);
 	}
 
-	KToggleAction *pt =
-		new KToggleAction(name, /* "kpilot" -- component icon, */ 0,
+	TDEToggleAction *pt =
+		new TDEToggleAction(name, /* "kpilot" -- component icon, */ 0,
 		TQT_TQOBJECT(p), TQT_SLOT(slotShowComponent()),
 		actionCollection(), actionname);
 
@@ -717,7 +717,7 @@ void KPilotInstaller::optionsConfigureToolbars()
 	FUNCTIONSETUP;
 	// use the standard toolbar editor
 	// This was added in KDE 3.1
-	saveMainWindowSettings( KGlobal::config(), autoSaveGroup() );
+	saveMainWindowSettings( TDEGlobal::config(), autoSaveGroup() );
 	KEditToolbar dlg(actionCollection());
 	connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_TQOBJECT(this), TQT_SLOT(slotNewToolbarConfig()));
 	dlg.exec();
@@ -729,7 +729,7 @@ void KPilotInstaller::slotNewToolbarConfig()
 	FUNCTIONSETUP;
 	// recreate our GUI
 	createGUI();
-	applyMainWindowSettings( KGlobal::config(), autoSaveGroup() );
+	applyMainWindowSettings( TDEGlobal::config(), autoSaveGroup() );
 }
 
 void KPilotInstaller::slotResetLink()
@@ -985,13 +985,13 @@ void KPilotInstaller::componentUpdate()
 //
 //
 //
-static KCmdLineOptions kpilotoptions[] = {
+static TDECmdLineOptions kpilotoptions[] = {
 	{"s", 0, 0},
 	{"setup",
 		I18N_NOOP("Setup the Pilot device, conduits and other parameters"),
 		0L},
 	{"debug <level>", I18N_NOOP("Set debugging level"), "0"},
-	KCmdLineLastOption
+	TDECmdLineLastOption
 };
 
 
@@ -1012,10 +1012,10 @@ int main(int argc, char **argv)
 {
 	FUNCTIONSETUP;
 
-	KAboutData about("kpilot", I18N_NOOP("KPilot"),
+	TDEAboutData about("kpilot", I18N_NOOP("KPilot"),
 		KPILOT_VERSION,
-		"KPilot - HotSync software for KDE\n\n",
-		KAboutData::License_GPL,
+		"KPilot - HotSync software for TDE\n\n",
+		TDEAboutData::License_GPL,
 		"(c) 1998-2000,2001, Dan Pilone (c) 2000-2006, Adriaan de Groot",
 		0L,
 		"http://www.kpilot.org/"
@@ -1047,10 +1047,10 @@ int main(int argc, char **argv)
 	about.addCredit("Bertjan Broeksema",
 		I18N_NOOP("VCalconduit state machine, CMake"));
 
-	KCmdLineArgs::init(argc, argv, &about);
-	KCmdLineArgs::addCmdLineOptions(kpilotoptions, "kpilot");
+	TDECmdLineArgs::init(argc, argv, &about);
+	TDECmdLineArgs::addCmdLineOptions(kpilotoptions, "kpilot");
 	KUniqueApplication::addCmdLineOptions();
-	KCmdLineArgs *p = KCmdLineArgs::parsedArgs();
+	TDECmdLineArgs *p = TDECmdLineArgs::parsedArgs();
 
 #ifdef DEBUG
 	KPilotConfig::getDebugLevel(p);
@@ -1126,7 +1126,7 @@ int main(int argc, char **argv)
 
 	TQTimer::singleShot(0,tp,TQT_SLOT(startDaemonIfNeeded()));
 
-	KGlobal::dirs()->addResourceType("pilotdbs",
+	TDEGlobal::dirs()->addResourceType("pilotdbs",
 		CSL1("share/apps/kpilot/DBBackup"));
 	tp->show();
 	a.setMainWidget(tp);
